struct CourseUnitResponsibilities {
code: String,
validity_period: Option<SisuCourseInfoValidityPeriod>,
responsibility_infos: Vec<ResponsibilityInfo>,
organisations: Vec<CourseUnitOrganisation>,
completion_methods: Vec<CompletionMethodAssessmentItems>,
}Expand description
The parts of a Sisu course unit version that say who is responsible for it. Kept separate from SisuCourseInfoElement so an odd field on an old version cannot break the lookup.
Fields
code: Stringvalidity_period: Option<SisuCourseInfoValidityPeriod>responsibility_infos: Vec<ResponsibilityInfo>organisations: Vec<CourseUnitOrganisation>completion_methods: Vec<CompletionMethodAssessmentItems>Trait Implementations
Sourceimpl Debug for CourseUnitResponsibilities
impl Debug for CourseUnitResponsibilities
Sourceimpl<'de> Deserialize<'de> for CourseUnitResponsibilities
impl<'de> Deserialize<'de> for CourseUnitResponsibilities
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more